# dataden

Developed to create mock data for dates in a sequential process.

For example, if a company has a program that has four steps, it will create date data in sequential order.
It also allows users to indicate that a percentage of a column should be null (to account for the sequential data never reaching the last step).